@@ -11,11 +11,18 @@ import pytest
 
 from hdx.utilities.downloader import Download, DownloadError
 from hdx.utilities.session import SessionError
+from hdx.utilities.useragent import UserAgent
 
 
 class TestDownloader:
     downloaderfoldername = 'downloader'
 
+    @pytest.fixture(scope='class', autouse=True)
+    def useragent(self):
+        UserAgent.set_global('test')
+        yield
+        UserAgent.clear_global()
+
     @pytest.fixture(scope='class')
     def downloaderfolder(self, fixturesfolder):
         return join(fixturesfolder, self.downloaderfoldername)
@@ -75,6 +82,8 @@ class TestDownloader:
         monkeypatch.setenv('BASIC_AUTH', basicauth)
         with Download(basic_auth='12345') as downloader:
             assert downloader.session.auth == ('user', 'pass')
+        with Download(extra_params_yaml=extraparamsyamltree, extra_params_lookup='mykey') as downloader:
+            assert downloader.session.auth == ('user', 'pass')
         monkeypatch.delenv('BASIC_AUTH')
         with pytest.raises(SessionError):
             Download(auth=('u', 'p'), basic_auth='Basic xxxxxxxxxxxxxxxx')
@@ -86,6 +95,8 @@ class TestDownloader:
             Download(auth=('u', 'p'), extra_params_yaml=extraparamsyamltree, extra_params_lookup='mykey')
         with pytest.raises(SessionError):
             Download(basic_auth_file=basicauthfile, extra_params_yaml=extraparamsyamltree, extra_params_lookup='mykey')
+        with pytest.raises(SessionError):
+            Download(extra_params_yaml=extraparamsyamltree, extra_params_lookup='missingkey')
         with pytest.raises(IOError):
             Download(basic_auth_file='NOTEXIST')
         extraparamsjson = join(downloaderfolder, 'extra_params.json')
@@ -119,6 +130,13 @@ class TestDownloader:
             assert 'param2=value3%2B7' in full_url
             assert 'param3=11' not in full_url
             assert 'basic_auth' not in full_url
+        with Download(extra_params_yaml=extraparamsyamltree, extra_params_lookup='mykey', use_env=False) as downloader:
+            assert downloader.session.auth == ('testuser', 'testpass')
+            full_url = downloader.get_full_url(test_url)
+            assert 'param1=value+1' in full_url
+            assert 'param2=value2' in full_url
+            assert 'param3=11' in full_url
+            assert 'basic_auth' not in full_url
         monkeypatch.delenv('EXTRA_PARAMS')
         with pytest.raises(SessionError):
             Download(extra_params_dict={'key1': 'val1'}, extra_params_json=extraparamsjson)
@@ -151,7 +169,7 @@ class TestDownloader:
         with Download() as downloader:
             downloader.setup(postfixtureurl, post=True)
             headers = downloader.response.headers
-            assert bool(re.match(r'3[56]\d', headers['Content-Length'])) is True
+            assert bool(re.match(r'2\d\d', headers['Content-Length'])) is True
             downloader.setup('%s?id=10&lala=a' % getfixtureurl, post=False,
                              parameters=OrderedDict([('b', '4'), ('d', '3')]))
             assert downloader.get_json()['args'] == OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')])
@@ -220,6 +238,10 @@ class TestDownloader:
             downloader.download('%s?id=3&lala=b' % postfixtureurl, post=True,
                                          parameters=OrderedDict([('a', '3'), ('c', '2')]))
             assert downloader.get_json()['form'] == OrderedDict([('a', '3'), ('c', '2'), ('id', '3'), ('lala', 'b')])
+        with Download(rate_limit=True) as downloader:
+            downloader.download('%s?id=10&lala=a' % getfixtureurl, post=False,
+                                parameters=OrderedDict([('b', '4'), ('d', '3')]))
+            assert downloader.get_json()['args'] == OrderedDict([('b', '4'), ('d', '3'), ('id', '10'), ('lala', 'a')])
 
     def test_download_tabular_key_value(self, fixtureurl, fixtureprocessurl):
         with Download() as downloader:
@@ -259,3 +281,6 @@ class TestDownloader:
             assert result == {'header1': {'3': 'coal', '2': 'gas'},
                               'header3': {'3': '7.4', '2': '6.5'},
                               'header4': {'3': 'needed', '2': 'n/a'}}
+
+    def test_get_column_positions(self):
+        assert Download.get_column_positions(['a', 'b', 'c']) == {'a': 0, 'b': 1, 'c': 2}
